@@ -17,3 +17,6 @@ class EnumeratedType(Enumerated):
     def create_field_list(self, per_bytes):
         decoded = decode_enumerated(self, per_bytes)
         return decoded
+
+    def to_dict(self, is_root=True):
+        return self.namedValues[int(self)]
