@@ -5,7 +5,7 @@ from asn1PERser.classes.module import already_filled_template
 
 class BooleanType(SimpleType):
     def __init__(self):
-        super().__init__()
+        super(BooleanType, self).__init__()
         self.typereference = self.__class__.__name__
 
     def fill_template(self, has_parent=False):
@@ -26,6 +26,3 @@ class BooleanType(SimpleType):
         if value == 'TRUE':
             return True
         return False
-
-    def __repr__(self):
-        return '\t' + super().__repr__() + '\n'
