@@ -3,8 +3,5 @@ from ..type import SimpleType
 
 class NullType(SimpleType):
     def __init__(self):
-        super().__init__()
+        super(NullType, self).__init__()
         self.typereference = "NULL"
-
-    def __repr__(self):
-        return '\t' + super().__repr__() + '\n'
