@@ -3,8 +3,5 @@ from ..type import SimpleType
 
 class NumericString(SimpleType):
     def __init__(self):
-        super().__init__()
+        super(NumericString, self).__init__()
         self.typereference = "NumericString"
-
-    def __repr__(self):
-        return '\t' + super().__repr__() + '\n'
